ENUM_CLASS = "Enum"
FIELDS = "fields"
LOGICAL_TYPE = "logicalType"
NAME = "name"
NULL = "null"
OPTIONAL = "Optional"
SYMBOLS = "symbols"
TYPE = "type"
ITEMS = "items"
LIST = "List"
VALUES = "values"
DICT = "Dict"
